Setting Up Your Project

# Windows

Open project | properties in Microsoft Visual Studio.

- C/C++ | Code Generation | Enable C++ Exceptions, should be Yes.
- C/C++ | Code Generation | Runtime Library, should be set to Multithreaded DLL or Debug Multithreaded DLL.
- C/C++ | General | Additional Include Directories add the root quickfix directory.
- Linker | Input | Additional Dependencies, must contain quickfix.lib and ws2_32.lib.
- Linker | General | Additional Library Directories, add the quickfix/lib directory.

# Linux/Solaris

- Exceptions must be enabled with -fexceptions
- The -finline-functions optimization is recommended.
- Quickfix library must be linked in with -lquickfix
- Quickfix makes use of pthreads and libxml. These must be linked in with -lpthread, -lxml2 and -lz
- On Solaris you must link with -lnsl and -lsocket
- GNU `ld` is a one-pass linker. Put more generally useful libraries (libsocket) last on the command line.